:
########################################################################
# Copyright (C) 1990
# FourGen Software Technologies, Inc. Edmonds, Washington USA
# Use, modification, duplication, and/or distribution of this
# software is limited to the terms of the software agreement.
# Sccsid:  @(#)  .../install/all/acct_ins.sh  1.16  Delta: 3/28/91
########################################################################
dn=/dev/null
DBDATE=mdy2/                 ; export DBDATE
SHELL=/bin/sh                ; export SHELL
archiver=ar
fourgen_ver=post_3.5

# set some defaults (if not already set)
if test ${INFORMIXDIR:=empty} = empty
then
    test -d /usr/informix && INFORMIXDIR=/usr/informix
    test -d /usr2/informix && INFORMIXDIR=/usr2/informix
    if test $INFORMIXDIR = empty
    then
        echo "The \$INFORMIXDIR system variable needs to be set." 1>&2
        exit 1
    else
        export INFORMIXDIR
    fi
fi

: ${fd:=$fg}; export fd
PATH=$INFORMIXDIR/bin:$fd/bin:$PATH; export PATH

# set the module-specific variables
if test $# -lt 2
then
    echo "Syntax: $0 module \"module name\"" 1>&2
    exit 1
fi
module=$1
mod_name=$2

# check for Informix 1.10 vs. Informix 4.0 or later.  
# first, test for the existence of the 4gl copyright file
if test -f $INFORMIXDIR/etc/I4GL-cr 
then
  if grep ' 1\.10' $INFORMIXDIR/etc/I4GL-cr > $dn 2> $dn
  then  # pre 4.0
    infmx_ver=pre_4.0   ; export infmx_ver
    echo the version of INFORMIX is pre 4.0
  else  # 4.0 or post 4.0
    infmx_ver=post_4.0  ; export infmx_ver
    echo the version of INFORMIX is 4.0 or later
  fi
else  # 4gl copyright file does not exist, must be running under RDS
  echo the 4gl file did not exist, check for the RDS file
  if test -f $INFORMIXDIR/etc/I4GP-cr 
  then
    if grep ' 1\.10' $INFORMIXDIR/etc/I4GP-cr > $dn 2> $dn
    then  # pre 4.0
      infmx_ver=pre_4.0  ; export infmx_ver
      echo the version of INFORMIX is pre 4.0
    else  # 4.0 or post 4.0
      infmx_ver=post_4.0 ; export infmx_ver
      echo the version of INFORMIX is 4.0 or later
    fi
  else 
  echo "\ncopyright files have been corrupted in $INFORMIXDIR/etc"
  echo "cannot determine version of Informix"
  echo "pre 3.5 report/posting programs will not be modified to run under 4.0\n"
  fi
fi

#--------------
# check for module being installed and version number of product
  
# 1st check to see if this is payroll and if so, is it pre 3.2
# payroll is a special case - it has been updated to incorporate
# 3.5 standards for libraries, etc, but will not actually become
# 3.5 until it is regenerable

if test $module = "py"
then
  tmp_ver=`sed -n '/version/s/version="\([0-9]*\.[0-9]*\)\..*$/v\1/p' $fg/accounting/install/$module/def`
  # compare modified version number to to 3.20
  if expr "$tmp_ver" \>= v3.20
  then
    fourgen_ver=post_3.5
  else
    fourgen_ver=pre_3.5
  fi
else  # module being installed is NOT py (payroll)

  # check to see if non payroll module is version 3.5 or greater
  # convert version num in $fg/acc*/install/$module/def file to x.xx format

  tmp_ver=`sed -n '/version/s/version="\([0-9]*\.[0-9]*\)\..*$/v\1/p' $fg/accounting/install/$module/def`

  # compare modified version number to to 3.50
  if expr "$tmp_ver" \>= v3.50
  then      # (3.5 and post 3.5 modules)
   fourgen_ver=post_3.5
    # note: not necessary to compile the local module library 
    # that library is compiled when the module Makefile is processed
  else      # pre 3.5 modules
    # compile the lib.4gm/$module library
    fourgen_ver=pre_3.5
  fi
fi

#--------------
# determine if this is source or retail
if test -f $fg/accounting/all.4gm/lib.4gs/init.4gl
  then source=yes
  else source=no
fi

# get rid of duplicates in DBPATH; make sure fourgen's is first, but
# after that, preserve the original order.
DBPATH=$fg/accounting/data:$DBPATH
db_dirs=`echo $DBPATH | sed 's/:/ /g'`
dup_dir_chk=" :"
DBPATH=`for db_dir in $db_dirs
        do
            if expr "$dup_dir_chk" : ".*:$db_dir:" > /dev/null
            then :
            else
                echo $db_dir
                dup_dir_chk=$dup_dir_chk$db_dir:
            fi
        done`
DBPATH=`echo $DBPATH | sed 's/ /:/g'`; export DBPATH

# set MAKE and DBMERGE for retail vs. source
MAKE=make
DBMERGE=$module/dbmerge.4ge
ifx=4GL
if test -x $INFORMIXDIR/bin/fglpc
then
    MAKE=make.rds
    DBMERGE="fglgo $module/dbmerge.4gi"
    ifx=RDS
fi
if test $source = no
then
    MAKE=/bin/true
    if test "$ifx" = "RDS"
    then
        DBMERGE="fglgo $module/dbmerge.4gi"
    fi
fi
export MAKE

#--------------
# make sure the libraries are made and installed
if test $module != "all"
then
    err=no
    if test "$ifx" = "4GL"
    then
        test -f $fg/lib/scr.a || err=yes
        test -f $fg/lib/report.a || err=yes
        test -f $fg/lib/standard.a || err=yes
        test -f $fg/lib/user_ctl.a || err=yes
    else
        test -d $fg/lib/scr.RDS || err=yes
        test -d $fg/lib/report.RDS || err=yes
        test -d $fg/lib/standard.RDS || err=yes
        test -d $fg/lib/user_ctl.RDS || err=yes
    fi
    if test "$err" = "yes"
    then
        echo "Some or all of the libraries in $fg/lib have
not been installed and/or compiled.
Please make sure FourGen Accounting: Base Files has
been installed correctly.
This install is looking for Informix-$ifx compiled libraries." 1>&2
    fi
fi

#--------------
# if we are a source product, then we want to change the release number
# in the acknowledgements and def files.
if test "$source" = "no"
then
    sed -e '/^version/s/0\([0-9]\)"/1\1"/' \
           $fg/accounting/install/$module/def > /tmp/def$$ &&
           mv /tmp/def$$ $fg/accounting/install/$module/def
    ack=$fg/accounting/data/$module/data.sample/stxacknd.unl
    sed -e '/FourGen Accounting/s/0\([0-9]\)"/1\1"/' \
           $ack > /tmp/ack$$ &&
           mv /tmp/ack$$ $ack
    ack=$fg/accounting/data/$module/data.standard/stxacknd.unl
    sed -e '/FourGen Accounting/s/0\([0-9]\)"/1\1"/' \
           $ack > /tmp/ack$$ &&
           mv /tmp/ack$$ $ack
fi

#--------------
# in altos unix, some installations use xar as their archiver.  if
# installing basefiles and this is the case, change our archiver to
# match.
if test $module = all
then
    # if the /bin/xar exists and this is source that is being installed...
    if test -x /bin/xar -a $source = yes
    then
        # set libfile to 
        libfile=`ls $INFORMIXDIR/lib/*.a | sed -n 1p`
        #  if table of contents for $libfile prints
        if /bin/xar t $libfile >$dn
        then
            archiver=xar
            sed "s/ARCMD=ar/ARCMD=xar/" < $fg/Make/library \
                > /tmp/make$$ &&
                mv /tmp/make$$ $fg/Make/library
        fi
        if sed "s/ar /xar /" < $fg/bin/lib_check > /tmp/make$$ 2>$dn
        then
            mv /tmp/make$$ $fg/bin/lib_check
            chmod 555 $fg/bin/lib_check
        fi
    fi
fi

#--------------
# make dbmerge
cd $fg/accounting/data/$module
$MAKE || exit 1
cd $fg/accounting/data

# if installing basefiles, make minisql
if test $module = all
then
    rm -f minisql.4gs/minisql.4ge
    $MAKE || exit 1
fi

# install the databases & data

# merge the new schemas into other existing databases
$fg/accounting/bin/merge_db $module

echo "Creating $mod_name tables for the standard database..."
$DBMERGE -d standard -l $module/data.standard -log `pwd` || exit 1
chown informix standard.dbs >$dn 2>&1
chgrp informix standard.dbs >$dn 2>&1
chmod 666 standard.log > $dn 2>&1
chgrp informix standard.log > $dn 2>&1
chown informix standard.log > $dn 2>&1
# check the indexes
$DBMERGE -d standard -i || exit 1

echo "Creating $mod_name tables for the sample database..."
$DBMERGE -d sample -l $module/data.sample -log `pwd` || exit 1
chown informix sample.dbs >$dn 2>&1
chgrp informix sample.dbs >$dn 2>&1
chmod 666 sample.log > $dn 2>&1
chgrp informix sample.log > $dn 2>&1
chown informix sample.log > $dn 2>&1
# check the indexes
$DBMERGE -d sample -i || exit 1

#--------------
# Compile the source code
if test $source = yes
then
    # compile the user interface libraries
    if test $module = all
    then
        echo "Compiling the user interface libraries..."
        # screen library
        cd $fg/lib/scr.4gs
        $MAKE || exit 1
        if test $ifx = RDS
        then
          mv depend.rds ../scr.RDS/depend.RDS
          mv func_map.rds ../scr.RDS/func_map.RDS
          mv unresolved.rds ../scr.RDS/unresolved.RDS
        fi

        # report library
        cd $fg/lib/report.4gs
        $MAKE || exit 1
        if test $ifx = RDS
        then
          mv depend.rds ../report.RDS/depend.RDS
          mv func_map.rds ../report.RDS/func_map.RDS
          mv unresolved.rds ../report.RDS/unresolved.RDS
        fi

        # standard library
        cd $fg/lib/standard.4gs
        $MAKE || exit 1
        if test $ifx = RDS
        then
          mv depend.rds ../standard.RDS/depend.RDS
          mv func_map.rds ../standard.RDS/func_map.RDS
          mv unresolved.rds ../standard.RDS/unresolved.RDS
        fi

        # if the user control library does not exist then compile
        # user control null functions
        if test ! -d $fg/lib/user_ctl.4gs
        then
            echo "Compiling FourGen: User Control library..."
            cd $fg/lib/user_nul.4gs
            $MAKE || exit 1
            if test $ifx = RDS
            then
                mv depend.rds ../user_ctl.RDS/depend.RDS
                mv func_map.rds ../user_ctl.RDS/func_map.RDS
                mv unresolved.rds ../user_ctl.RDS/unresolved.RDS
            fi
        fi
    fi

    # if installing base files or g/l, make the g/l detail & summary
    # reports know if g/l is installed.  compile them if this is g/l.
    # if base files, they'll be compiled anyway later.
    if test $module = all -o $module = gl
    then
      cd $fg/accounting/all.4gm/o_gldetl.4gs
      ./make_gl.sh || exit 1
      if test $module = gl
      then
          $MAKE || exit 1
      fi
      cd $fg/accounting/all.4gm/o_glsmry.4gs
      ./make_gl.sh || exit 1
      if test $module = gl
      then
          $MAKE || exit 1
      fi
    fi

    #--------------
    if test "$fourgen_ver" = pre_3.5
    then
      cd $fg/accounting/lib.4gm/$module.4gs
      echo "Compiling the pre 3.5 accounting $mod_name library..."
      touch *.4gl
      $MAKE || exit 1 

      # test to see if the lib.4gm/all.4gs library was previously compiled

      if test -f $fg/accounting/lib.4gm/all.4gs/install_note
      then
        echo "$fg/accounting/lib.4gm/all.4gs library was previously compiled"
        echo 'no need to compile again'
      else  # library needs to be compiled
        cd $fg/accounting/lib.4gm/all.4gs
        # remove st_init from Makefile (it conflicts with init)
        # do not remove st_init from library; it is available for copying to 
        # a local library for users running in pre 3.5 environment
        echo 'removing the compiled version of st_init'

        rm -f ../lib.RDS/st_init.*
        # test to see if lib.a exists 
        if test -f ../lib.a
        then
          # determine if "ar" or "xar" being used as the archiver
          if test "$archiver" = ar
          then
            ar d ../lib.a st_init.o
          else
            xar d ../lib.a st_init.o
          fi
        fi

        # compile the lib.4gm/all.4gs library for pre 3.5 modules
        echo "Compiling the pre 3.5 lib.4gm/all.4gs library..."
        touch *.4gl
        $MAKE || exit 1  
        echo 'The lib.4gm/all.4gs library has been compiled' > install_note
      fi # end library compilation code

      # convert input and report programs to be 3.5 compatibility
      echo 'You now have the opportunity to convert your pre 3.5 module'
      echo 'being installed, making it 3.5 compatible.'
  
      while true
      do
      echo '\nDo you want more information on this process? (yes or no) \c'
      read response
        case "$response" in
          [yY]|[yY][eE][sS]) cat $fg/accounting/install/all/README
                            break;;
          [nN]|[nN][oO]) break;; 
          *) continue ;;
        esac
      done
  
      while true
      do
      echo "\nDo you want to convert programs in $module.4gm" 
      echo 'to be 3.5 compatible? (yes or no) \c'
      read response
        case "$response" in
          [yY]|[yY][eE][sS]) cd $fg/accounting/$module.4gm

          # o/e is a special case: it was created with a different
          # version of the code generator (only input programs are different
          # from other modules:

          if test "$module" = oe  
          then
            for dir in i_*4gs
            do
              cd $dir
              # append the st_init.4gl file (eliminating the globals line)
              # to the file: "t_main.4gl"
              cat $fg/accounting/lib.4gm/all.4gs/st_init.4gl | sed -n '13,$ p' >> t_main.4gl
              cd ..
            done
          else  # installing a non o/e pre 3.5 product
            for dir in i_*4gs
            do
              cd $dir
              $fg/bin/update.scr
              cd ..
            done
          fi

          for dir in o_*4gs p_*4gs
          do
            cd $dir
            $fg/bin/update.rpt
            cd ..
          done 
          break ;;
          [nN]|[nN][oO]) break;; 
          *) continue ;;
        esac
      done
    fi # end code pertaining strictly to pre 3.5 (and pre py 3.2) product
     
    #--------------
    # make the accounting programs
    cd $fg/accounting/$module.4gm
    echo "Compiling the accounting $mod_name programs..."
    touch */globals.4gl
    $MAKE || exit 1
fi  # end code pertaining strictly to source product

# Install the main accounting menu
if test -f $fg/accounting/bin/makemenu
then
    $fg/accounting/bin/makemenu > $fg/accounting/menu/mainmenu/main/menu
fi


